pub enum ExtensionError {
DuplicateName(String),
RegistryLocked,
StateSerialization {
name: String,
reason: String,
},
StateRestoration {
name: String,
reason: String,
},
CommandError(String),
Other(String),
}Expand description
Errors from extension operations.
Variants
DuplicateName(String)
An extension with the same name is already registered.
RegistryLocked
The registry has already been shared with hooks or an event sink.
StateSerialization
Extension state serialization failed.
StateRestoration
Extension state restoration failed.
CommandError(String)
An extension command returned an error.
Other(String)
A generic extension error.