pub struct StreamingProxy<H> { /* private fields */ }Expand description
Implementations
Sourceimpl<H: ProxyHandler> StreamingProxy<H>
impl<H: ProxyHandler> StreamingProxy<H>
Sourcepub fn new(handler: H, config: ProxyConfig) -> Self
pub fn new(handler: H, config: ProxyConfig) -> Self
Create a new proxy with the given handler and configuration.
Sourcepub fn run<R: BufRead, W: Write>(
self,
reader: R,
writer: W,
cancel: CancellationToken,
) -> Result<W, StreamingProxyError>
pub fn run<R: BufRead, W: Write>( self, reader: R, writer: W, cancel: CancellationToken, ) -> Result<W, StreamingProxyError>
Run the proxy until input is exhausted, a quit command is received, or cancellation fires.
Returns the writer on success, or an error if the proxy failed.